:github_url: https://github.com/stephane-caron/robot_descriptions/tree/master/doc/src/developer-notes.rst

***************
Developer notes
***************

Adding a new model
==================

...

Testing locally
===============

To run all continuous integration checks locally, go to the repository folder and run:

.. code:: bash

    tox -e py

This command will run linters and unit tests.
